- Job Data Grid
- Jobs List
- Job Details
- Job Submit
- System Health

AUTO
-
System Health
-
Please pick an existing job.
you are preparing to submit the workflow
-
for dataset
-
for job label
-
please make your changes below
-
Start Workflow
Refresh Settings
AUTO
-
Job vs. Data Grid
Please click on a white box to submit the data for processing. Click any other box to see details about the ongoing or finished processing.

legend |  |  | not submitted |  |  | in progress |  |  | finished |  |  | error |  |  | cancelled

-
AUTO
-
Recent Jobs
-
AUTO
-
Job Summary
-
Workflow Settings -
-
-
-
New Workflow
Task Progress
-
Job Actions
-
Job Variables
-